package cs451.net.handler;

import cs451.net.NetManager;
import cs451.net.event.NetEvent;
import cs451.parser.Host;
import cs451.parser.Parser;

import java.util.Objects;
import java.util.concurrent.atomic.AtomicBoolean;

public abstract class NetEventHandlerAbstract implements NetEventHandlerInterface {

    private final Class<? extends NetEventHandlerAbstract> deliverLayer;
    private final Class<? extends NetEventHandlerAbstract> broadcastLayer;

    public final AtomicBoolean active = new AtomicBoolean(true);


    NetEventHandlerAbstract(Class<? extends NetEventHandlerAbstract> deliverLayer, Class<? extends NetEventHandlerAbstract> broadcastLayer) {
        this.deliverLayer = deliverLayer;
        this.broadcastLayer = broadcastLayer;
    }



    public void deliverNextSync(NetEvent ne){
        NetManager.deliverSync(deliverLayer,ne);
    }
    public void sendNextSync(NetEvent ne){
        NetManager.sendSync(broadcastLayer,ne);
    }
    public void crashNextSync(NetEvent ne){
        NetManager.crashSync(deliverLayer,ne);
    }

    public void deliverNextAsync(NetEvent ne){
        NetManager.deliver(deliverLayer,ne);
    }
    public void sendNextAsync(NetEvent ne){
        NetManager.send(broadcastLayer,ne);
    }
    public void crashNextAsync(NetEvent ne) {
        NetManager.crash(deliverLayer,ne);
    }

    public void start(Host h, Parser p) {
        Objects.requireNonNull(h);
        Objects.requireNonNull(p);
        active.set(true);
    }

    public void stop() {
        active.set(false);
    }

}
